Documentation
¶
Index ¶
- Variables
- type Projector
- func (p *Projector) GetActiveSignal(ctx context.Context, addr string) (bool, error)
- func (p *Projector) GetBlanked(ctx context.Context, addr string) (bool, error)
- func (p *Projector) GetInfo(ctx context.Context, addr string) (interface{}, error)
- func (p *Projector) GetInput(ctx context.Context, addr string) (string, error)
- func (p *Projector) GetPower(ctx context.Context, addr string) (string, error)
- func (p *Projector) SendCommand(ctx context.Context, addr string, cmd []byte) ([]byte, error)
- func (p *Projector) SetBlanked(ctx context.Context, addr string, blanked bool) error
- func (p *Projector) SetInput(ctx context.Context, addr string, input string) error
- func (p *Projector) SetPower(ctx context.Context, addr string, power string) error
Constants ¶
This section is empty.
Variables ¶
var ( // BlankMuteStatus gets the blank & mute status of the projector BlankMuteStatus = []byte{0x00, 0x85, 0x00, 0x00, 0x01, 0x03, 0x89} // Blank blanks the projector Blank = []byte{0x02, 0x10, 0x00, 0x00, 0x00, 0x12} // Unblank unblanks the projector Unblank = []byte{0x02, 0x11, 0x00, 0x00, 0x00, 0x13} )
var ( // ActiveSignal whether or not the projector's input has signal or not ActiveSignal = []byte{0x00, 0xBF, 0x00, 0x00, 0x01, 0x02, 0xC2} // InputStatus returns the current input of the projector InputStatus = []byte{0x00, 0x85, 0x00, 0x00, 0x01, 0x02, 0x88} // ChangeInput changes the input of the projector ChangeInput = []byte{0x02, 0x03, 0x00, 0x00, 0x02, 0x01, 0x00, 0x00} )
var ( // PowerStatus gets the projector's power status PowerStatus = []byte{0x00, 0x85, 0x00, 0x00, 0x01, 0x01, 0x87} // PowerOn powers on the projector PowerOn = []byte{0x02, 0x00, 0x00, 0x00, 0x00, 0x02} // PowerStandby powers off the projector PowerStandby = []byte{0x02, 0x01, 0x00, 0x00, 0x00, 0x03} )
Functions ¶
This section is empty.
Types ¶
type Projector ¶
type Projector struct {
// contains filtered or unexported fields
}
func (*Projector) GetActiveSignal ¶
func (*Projector) GetBlanked ¶
func (*Projector) SendCommand ¶
SendCommand sends the byte array to the desired address of projector
func (*Projector) SetBlanked ¶
Click to show internal directories.
Click to hide internal directories.